@@ -1,7 +1,7 @@
 package App::osnames;
 
-our $DATE = '2014-12-18'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2015-07-01'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,7 +47,7 @@ _
 die "Can't generate list_osnames function: $res->[0] - $res->[1]"
     unless $res->[0] == 200;
 
-$SPEC{list_osnames}{args}{q}{pos} = 0;
+$SPEC{list_osnames}{args}{query}{pos} = 0;
 $SPEC{list_osnames}{examples} = [
     {
         argv    => [qw/ux/],
@@ -78,7 +78,11 @@ App::osnames - List possible $^O ($OSNAME) values, with description
 
 =head1 VERSION
 
-This document describes version 0.07 of App::osnames (from Perl distribution App-osnames), released on 2014-12-18.
+This document describes version 0.08 of App::osnames (from Perl distribution App-osnames), released on 2015-07-01.
+
+=head1 SEE ALSO
+
+L<Perl::osnames>
 
 =head1 FUNCTIONS
 
@@ -89,7 +93,7 @@ List possible $^O ($OSNAME) values, with description.
 
 Examples:
 
- list_osnames( q => "ux");
+ list_osnames( query => "ux");
 
 
 String search.
@@ -122,7 +126,7 @@ Only return records where the 'description' field equals specified value.
 
 Only return records where the 'description' field contains specified text.
 
-=item * B<description.in> => I<array>
+=item * B<description.in> => I<array[str]>
 
 Only return records where the 'description' field is in the specified values.
 
@@ -146,7 +150,7 @@ Only return records where the 'description' field is greater than or equal to sp
 
 Only return records where the 'description' field does not contain specified text.
 
-=item * B<description.not_in> => I<array>
+=item * B<description.not_in> => I<array[str]>
 
 Only return records where the 'description' field is not in the specified values.
 
@@ -164,11 +168,11 @@ Return array of full records instead of just ID fields.
 
 By default, only the key (ID) field is returned per result entry.
 
-=item * B<fields> => I<array>
+=item * B<fields> => I<array[str]>
 
 Select fields to return.
 
-=item * B<q> => I<str>
+=item * B<query> => I<str>
 
 Search.
 
@@ -183,7 +187,7 @@ specify descending order instead of the default ascending.
 
 Only return records where the 'tags' field equals specified value.
 
-=item * B<tags.has> => I<array>
+=item * B<tags.has> => I<array[str]>
 
 Only return records where the 'tags' field is an array/list which contains specified value.
 
@@ -195,7 +199,7 @@ Only return records where the 'tags' field equals specified value.
 
 Only return records where the 'tags' field does not equal specified value.
 
-=item * B<tags.lacks> => I<array>
+=item * B<tags.lacks> => I<array[str]>
 
 Only return records where the 'tags' field is an array/list which does not contain specified value.
 
@@ -207,7 +211,7 @@ Only return records where the 'value' field equals specified value.
 
 Only return records where the 'value' field contains specified text.
 
-=item * B<value.in> => I<array>
+=item * B<value.in> => I<array[str]>
 
 Only return records where the 'value' field is in the specified values.
 
@@ -231,7 +235,7 @@ Only return records where the 'value' field is greater than or equal to specifie
 
 Only return records where the 'value' field does not contain specified text.
 
-=item * B<value.not_in> => I<array>
+=item * B<value.not_in> => I<array[str]>
 
 Only return records where the 'value' field is not in the specified values.
 
@@ -253,8 +257,6 @@ as list/array (field value, field value, ...).
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -264,11 +266,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
-=head1 SEE ALSO
-
-L<Perl::osnames>
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -292,7 +290,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
